@@ -17,6 +17,14 @@ make \
     NO_INSTALL_HARDLINKS=1 \
     all strip install
 
+# build osxkeychain
+if [[ $(uname) == "Darwin" ]]; then
+  pushd contrib/credential/osxkeychain
+  make -e
+  cp -avf git-credential-osxkeychain $PREFIX/bin
+  popd
+fi
+
 git config --system http.sslVerify true
 git config --system http.sslCAPath "${PREFIX}/ssl/cacert.pem"
 git config --system http.sslCAInfo "${PREFIX}/ssl/cacert.pem"
@@ -24,3 +32,5 @@ git config --system http.sslCAInfo "${PREFIX}/ssl/cacert.pem"
 # Install completion files
 mkdir -p $PREFIX/share/bash-completion/completions
 cp contrib/completion/git-completion.bash $PREFIX/share/bash-completion/completions/git
+
+
